package gs

import java.io.File
import org.eclipse.jgit.lib.Constants
import org.eclipse.jgit.lib.Repository
import org.eclipse.jgit.revwalk.RevWalk
import org.eclipse.jgit.storage.file.FileRepositoryBuilder
import scala.collection.JavaConverters._
import scala.util.Try

object Git {

  private lazy val repo: Repository = {
    val builder = new FileRepositoryBuilder()
    builder.setGitDir(new File(".")).findGitDir().build()
  }

  def getLatestSemVer(): Option[SemVer] = {
    val walk = new RevWalk(repo)
    val result = repo
      .getRefDatabase()
      .getRefsByPrefix(Constants.R_TAGS)
      .asScala
      .map(ref => walk.parseTag(ref.getObjectId()))
      .sortBy(_.getTaggerIdent().getWhenAsInstant())
      .headOption
      .map(_.getTagName())
      .map(normalizeTagName)
      .flatMap(SemVer.parse)

    walk.dispose()
    result
  }

  private def normalizeTagName(tag: String): String =
    tag.trim().stripPrefix("v")

}
