package gs

import sbt._

object SemVerKeys {

  /** SBT Setting Key for the latest known project version.
    *
    * This value is automatically derived from Git by looking at the most recent
    * tag. If the project does not yet have any tags, the value 0.1.0 is used.
    */
  lazy val latestVersion = settingKey[String](
    "Latest Git-tagged project version, or 0.1.0 if no tags exist."
  )

  /** SBT Setting Key for the working project version - used if there are any
    * non-committed changes.
    *
    * This value is automatically derived by taking the latest version, and
    * either incrementing the revision by 1 or just using 0.1.0 if the project
    * does not have any Git tags.
    */
  lazy val workingVersion = settingKey[String](
    "Revision level increment of the latest version, or 0.1.0 if no tags exist."
  )

}
